@@ -86,7 +86,8 @@ floodlight_2_by_continuous <- function(
   # remove rows with na
   dt_1 <- stats::na.omit(dt_1[, c(iv_name, dv_name, mod_name), with = F])
   # unique values in iv
-  iv_unique_values <- unique(dt_1[, get(iv_name)])
+  iv_unique_values <- sort(unique(dt_1[, get(iv_name)]))
+  iv_unique_values_character <- as.character(iv_unique_values)
   # check if iv is binary
   num_of_levels_in_iv <- length(iv_unique_values)
   if (num_of_levels_in_iv != 2) {
@@ -102,14 +103,15 @@ floodlight_2_by_continuous <- function(
     iv_level_2 <- iv_unique_values[2]
   } else {
     # check if the iv levels match
-    if (!identical(sort(unique(iv_level_order)),
-                   sort(iv_unique_values))) {
+    iv_level_order_character <- as.character(iv_level_order)
+    if (!identical(iv_unique_values_character,
+                   iv_level_order_character)) {
       stop(paste0(
-        "The levels of independent variables do not match:\n",
+        "\nThe levels of independent variables do not match:\n",
         "iv_level_order input: ",
-        paste0(sort(unique(dt_1[, get(iv_name)])), collapse = ", "),
+        paste0(iv_level_order_character, collapse = ", "),
         "\nLevels of IV in the data set: ",
-        paste0(sort(unique(iv_level_order)), collapse = ", ")))
+        paste0(iv_unique_values_character, collapse = ", ")))
     }
     iv_level_1 <- iv_level_order[1]
     iv_level_2 <- iv_level_order[2]
